@@ -2,22 +2,25 @@
 #' @keywords internal
 #' @rdname rules-internal
 xrf_fit <-
-  function(formula,
-           data,
-           max_depth = 6,
-           nrounds = 15,
-           eta = 0.3,
-           colsample_bynode = NULL,
-           colsample_bytree = NULL,
-           min_child_weight = 1,
-           gamma = 0,
-           subsample = 1,
-           validation = 0,
-           early_stop = NULL,
-           counts = TRUE,
-           event_level = c("first", "second"),
-           lambda = 0.1,
-           ...) {
+  function(
+    formula,
+    data,
+    max_depth = 6,
+    nrounds = 15,
+    eta = 0.3,
+    colsample_bynode = NULL,
+    colsample_bytree = NULL,
+    min_child_weight = 1,
+    gamma = 0,
+    subsample = 1,
+    validation = 0,
+    early_stop = NULL,
+    counts = TRUE,
+    event_level = c("first", "second"),
+    lambda = 0.1,
+    objective = NULL,
+    ...
+  ) {
     converted <-
       parsnip::.convert_form_to_xy_fit(
         formula = formula,
@@ -38,7 +41,7 @@ xrf_fit <-
         subsample = subsample,
         validation = validation,
         early_stop = early_stop,
-        objective = NULL,
+        objective = objective,
         counts = counts,
         event_level = event_level
       )
@@ -76,35 +79,45 @@ xrf_fit <-
     res$family <- args$family
     res$levels <- get_levels(formula, data)
     res
-}
+  }
 
 process_mtry <- function(colsample_bytree, counts, n_predictors, is_missing) {
   if (!is.logical(counts)) {
-    rlang::abort("'counts' should be a logical value.")
+    cli::cli_abort("{.arg counts} should be a logical value.")
   }
 
-  ineq <- if (counts) {"greater"} else {"less"}
-  interp <- if (counts) {"count"} else {"proportion"}
-  opp <- if (!counts) {"count"} else {"proportion"}
+  ineq <- if (counts) {
+    "greater"
+  } else {
+    "less"
+  }
+  interp <- if (counts) {
+    "count"
+  } else {
+    "proportion"
+  }
+  opp <- if (!counts) {
+    "count"
+  } else {
+    "proportion"
+  }
 
   if ((colsample_bytree < 1 & counts) | (colsample_bytree > 1 & !counts)) {
-    rlang::abort(
-      paste0(
-        "The supplied argument `mtry = ", colsample_bytree, "` must be ",
-        ineq, " than or equal to 1. \n\n`mtry` is currently being interpreted ",
-        "as a ", interp, " rather than a ", opp, ". Supply `counts = ", !counts,
-        "` to `set_engine()` to supply this argument as a ", opp, " rather than ",
-        # TODO: add a section to the linked parsnip docs on mtry vs mtry_prop
-        "a ", interp, ". \n\nSee `?details_rule_fit_xrf` for more details."
-      ),
-      call = NULL
+    cli::cli_abort(
+      c(
+        "The supplied argument `{.arg mtry} = {colsample_bytree}` must be {ineq} than or equal to 1.",
+        "i" = "{.arg mtry} is currently being interpreted as a {interp} rather than a {opp}.",
+        "i" = "Supply `{.arg counts} = {!counts}` to `set_engine()` to supply this argument as a {opp} rather than a {interp}.",
+        "i" = "See {.help details_rule_fit_xrf} for more details.",
+        call = NULL
+      )
     )
   }
 
   if (rlang::is_call(colsample_bytree)) {
     if (rlang::call_name(colsample_bytree) == "tune") {
-      rlang::abort(
-        paste0(
+      cli::cli_abort(
+        c(
           "The supplied `mtry` parameter is a call to `tune`. Did you forget ",
           "to optimize hyperparameters with a tuning function like `tune::tune_grid`?"
         ),
@@ -171,7 +184,6 @@ get_levels <- function(formula, data) {
   res
 }
 
-
 #' @export
 #' @keywords internal
 #' @rdname rules-internal
@@ -179,10 +191,11 @@ xrf_pred <- function(object, new_data, lambda = object$fit$lambda, type, ...) {
   lambda <- sort(lambda)
 
   res <- predict(object$fit, new_data, lambda = lambda, type = "response")
+  family <- rlang::as_name(object$fit$family)
   if (type != "prob") {
-    res <- organize_xrf_multi_pred(res, object, lambda, object$fit$family)
+    res <- organize_xrf_multi_pred(res, object, lambda, family)
   } else {
-    res <- organize_xrf_multi_prob(res, object, lambda, object$fit$family)
+    res <- organize_xrf_multi_prob(res, object, lambda, family)
   }
   res
 }
@@ -194,7 +207,9 @@ xrf_pred <- function(object, new_data, lambda = object$fit$lambda, type, ...) {
 multi_predict._xrf <-
   function(object, new_data, type = NULL, penalty = NULL, ...) {
     if (any(names(enquos(...)) == "newdata")) {
-      rlang::abort("Did you mean to use `new_data` instead of `newdata`?")
+      cli::cli_abort(
+        "Did you mean to use {.arg new_data} instead of {.arg newdata}?"
+      )
     }
     if (is.null(penalty)) {
       penalty <- object$fit$lambda
@@ -240,7 +255,7 @@ organize_xrf_class_prob <- function(x, object) {
     x <- x[, 1]
     x <- tibble(v1 = 1 - x, v2 = x)
   } else {
-    x <- x[, , 1]
+    x <- x[,, 1]
     x <- as_tibble(x)
   }
   colnames(x) <- object$lvl
@@ -253,24 +268,27 @@ organize_xrf_multi_pred <- function(x, object, penalty, fam) {
       res <- tibble(penalty = rep(penalty, nrow(x)), .pred = unname(x[, 1]))
     } else {
       res <-
-        tibble::as_tibble(x) %>%
-        dplyr::mutate(.row_number = 1:nrow(x)) %>%
-        tidyr::pivot_longer(cols = c(-.row_number), values_to = ".pred") %>%
-        dplyr::mutate(penalty = rep(penalty, nrow(x))) %>%
-        dplyr::select(-name) %>%
-        dplyr::group_by(.row_number) %>%
-        tidyr::nest() %>%
-        dplyr::ungroup() %>%
-        dplyr::select(-.row_number) %>%
+        as_tibble(x) |>
+        dplyr::mutate(.row_number = seq_len(nrow(x))) |>
+        tidyr::pivot_longer(cols = c(-.row_number), values_to = ".pred") |>
+        dplyr::mutate(penalty = rep(penalty, nrow(x))) |>
+        dplyr::select(-name) |>
+        dplyr::group_by(.row_number) |>
+        tidyr::nest() |>
+        dplyr::ungroup() |>
+        dplyr::select(-.row_number) |>
         setNames(".pred")
     }
   } else {
     if (fam == "binomial") {
       res <-
-        tibble::as_tibble(x) %>%
-        dplyr::mutate(.row_number = 1:nrow(x)) %>%
-        tidyr::pivot_longer(cols = c(-.row_number), values_to = ".pred_class") %>%
-        dplyr::select(-name) %>%
+        as_tibble(x) |>
+        dplyr::mutate(.row_number = seq_len(nrow(x))) |>
+        tidyr::pivot_longer(
+          cols = c(-.row_number),
+          values_to = ".pred_class"
+        ) |>
+        dplyr::select(-name) |>
         dplyr::mutate(
           .pred_class = ifelse(.pred_class >= .5, object$lvl[2], object$lvl[1]),
           .pred_class = factor(.pred_class, levels = object$lvl)
@@ -282,22 +300,25 @@ organize_xrf_multi_pred <- function(x, object, penalty, fam) {
       } else {
         # multipredict
         res <-
-          res %>%
-          dplyr::mutate(penalty = rep(penalty, nrow(x))) %>%
-          dplyr::group_by(.row_number) %>%
-          tidyr::nest() %>%
-          dplyr::ungroup() %>%
-          dplyr::select(-.row_number) %>%
+          res |>
+          dplyr::mutate(penalty = rep(penalty, nrow(x))) |>
+          dplyr::group_by(.row_number) |>
+          tidyr::nest() |>
+          dplyr::ungroup() |>
+          dplyr::select(-.row_number) |>
           setNames(".pred")
       }
     } else {
       # fam = "multinomial"
       res <-
-        apply(x, 3, function(x) apply(x, 1, which.max)) %>%
-        tibble::as_tibble() %>%
-        dplyr::mutate(.row_number = 1:nrow(x)) %>%
-        tidyr::pivot_longer(cols = c(-.row_number), values_to = ".pred_class") %>%
-        dplyr::select(-name) %>%
+        apply(x, 3, function(x) apply(x, 1, which.max)) |>
+        as_tibble() |>
+        dplyr::mutate(.row_number = seq_len(nrow(x))) |>
+        tidyr::pivot_longer(
+          cols = c(-.row_number),
+          values_to = ".pred_class"
+        ) |>
+        dplyr::select(-name) |>
         dplyr::mutate(
           .pred_class = object$lvl[.pred_class],
           .pred_class = factor(.pred_class, levels = object$lvl)
@@ -308,12 +329,12 @@ organize_xrf_multi_pred <- function(x, object, penalty, fam) {
       } else {
         # multi-predict
         res <-
-          res %>%
-          dplyr::mutate(penalty = rep(penalty, nrow(x))) %>%
-          dplyr::group_by(.row_number) %>%
-          tidyr::nest() %>%
-          dplyr::ungroup() %>%
-          dplyr::select(-.row_number) %>%
+          res |>
+          dplyr::mutate(penalty = rep(penalty, nrow(x))) |>
+          dplyr::group_by(.row_number) |>
+          tidyr::nest() |>
+          dplyr::ungroup() |>
+          dplyr::select(-.row_number) |>
           setNames(".pred")
       }
     }
@@ -324,49 +345,49 @@ organize_xrf_multi_pred <- function(x, object, penalty, fam) {
 organize_xrf_multi_prob <- function(x, object, penalty, fam) {
   if (fam == "binomial") {
     res <-
-      tibble::as_tibble(x) %>%
-      dplyr::mutate(.row_number = 1:nrow(x)) %>%
-      tidyr::pivot_longer(cols = c(-.row_number), values_to = ".pred_2") %>%
-      dplyr::mutate(penalty = rep(penalty, nrow(x))) %>%
-      dplyr::select(-name) %>%
-      dplyr::mutate(.pred_1 = 1 - .pred_2) %>%
+      as_tibble(x) |>
+      dplyr::mutate(.row_number = seq_len(nrow(x))) |>
+      tidyr::pivot_longer(cols = c(-.row_number), values_to = ".pred_2") |>
+      dplyr::mutate(penalty = rep(penalty, nrow(x))) |>
+      dplyr::select(-name) |>
+      dplyr::mutate(.pred_1 = 1 - .pred_2) |>
       dplyr::select(.row_number, penalty, .pred_1, .pred_2)
 
     if (length(penalty) == 1) {
       # predict
       res <-
-        res %>%
-        setNames(c(".row_number", "penalty", object$lvl)) %>%
+        res |>
+        setNames(c(".row_number", "penalty", object$lvl)) |>
         dplyr::select(-.row_number, -penalty)
     } else {
       # multi_predict
       res <-
-        res %>%
-        setNames(c(".row_number", "penalty", paste0(".pred_", object$lvl))) %>%
-        dplyr::group_by(.row_number) %>%
-        tidyr::nest() %>%
-        dplyr::ungroup() %>%
-        dplyr::select(-.row_number) %>%
+        res |>
+        setNames(c(".row_number", "penalty", paste0(".pred_", object$lvl))) |>
+        dplyr::group_by(.row_number) |>
+        tidyr::nest() |>
+        dplyr::ungroup() |>
+        dplyr::select(-.row_number) |>
         setNames(".pred")
     }
   } else {
     # fam = "multinomial"
     res <-
-      apply(x, 3, as_tibble) %>%
-      bind_rows() %>%
+      apply(x, 3, as_tibble) |>
+      dplyr::bind_rows() |>
       setNames(object$lvl)
 
     # good format for predict()
     if (length(penalty) > 1) {
       # multi_predict
       res <-
-        res %>%
-        dplyr::mutate(.row_number = rep(1:nrow(x), length(penalty))) %>%
-        dplyr::mutate(penalty = rep(penalty, each = nrow(x))) %>%
-        dplyr::group_by(.row_number) %>%
-        tidyr::nest() %>%
-        dplyr::ungroup() %>%
-        dplyr::select(-.row_number) %>%
+        res |>
+        dplyr::mutate(.row_number = rep(seq_len(nrow(x)), length(penalty))) |>
+        dplyr::mutate(penalty = rep(penalty, each = nrow(x))) |>
+        dplyr::group_by(.row_number) |>
+        tidyr::nest() |>
+        dplyr::ungroup() |>
+        dplyr::select(-.row_number) |>
         setNames(".pred")
     }
   }
@@ -377,10 +398,16 @@ organize_xrf_multi_prob <- function(x, object, penalty, fam) {
 #' @keywords internal
 #' @rdname rules-internal
 tunable.rule_fit <- function(x, ...) {
-  tibble::tibble(
+  tibble(
     name = c(
-      "mtry", "trees", "min_n", "tree_depth", "learn_rate",
-      "loss_reduction", "sample_size", "penalty"
+      "mtry",
+      "trees",
+      "min_n",
+      "tree_depth",
+      "learn_rate",
+      "loss_reduction",
+      "sample_size",
+      "penalty"
     ),
     call_info = list(
       list(pkg = "dials", fun = "mtry_prop"),
