@@ -1,10 +1,7 @@
-library(dplyr)
-
-# ------------------------------------------------------------------------------
-
 test_that("formula method", {
   skip_on_cran()
   skip_if_not_installed("xrf")
+  skip_if_not_installed("modeldata")
 
   ad_data <- make_ad_data()
 
@@ -14,33 +11,37 @@ test_that("formula method", {
       Class ~ .,
       data = ad_data$ad_mod,
       family = "binomial",
-      xgb_control = list(nrounds = 3, min_child_weight = 3, penalty = 1),
+      xgb_control = list(nrounds = 3, min_child_weight = 3),
       verbose = 0
     )
   rf_pred_exp <- predict(rf_fit_exp, ad_data$ad_pred, lambda = 1)[, 1]
-  rf_pred_exp <- factor(ifelse(rf_pred_exp >= 0.5, ad_data$lvls[2], ad_data$lvls[1]),
-                        levels = ad_data$lvls)
-  rf_pred_exp <- unname(rf_pred_exp)
-  rf_prob_exp <- predict(rf_fit_exp, ad_data$ad_pred, lambda = 1, type = "response")[, 1]
-
-  expect_error(
-    rf_mod <-
-      rule_fit(trees = 3, min_n = 3, penalty = 1) %>%
-      set_engine("xrf") %>%
-      set_mode("classification"),
-    NA
+  rf_pred_exp <- factor(
+    ifelse(rf_pred_exp >= 0.5, ad_data$lvls[2], ad_data$lvls[1]),
+    levels = ad_data$lvls
   )
+  rf_pred_exp <- unname(rf_pred_exp)
+  rf_prob_exp <- predict(
+    rf_fit_exp,
+    ad_data$ad_pred,
+    lambda = 1,
+    type = "response"
+  )[, 1]
+
+  expect_no_error({
+    set.seed(4526)
+    rf_mod <-
+      rule_fit(trees = 3, min_n = 3, penalty = 1) |>
+      set_engine("xrf") |>
+      set_mode("classification")
+  })
 
   set.seed(4526)
-  expect_error(
-    rf_fit <- fit(rf_mod, Class ~ ., data = ad_data$ad_mod),
-    NA
+  expect_no_error(
+    rf_fit <- fit(rf_mod, Class ~ ., data = ad_data$ad_mod)
   )
   rf_pred <- predict(rf_fit, ad_data$ad_pred)
   rf_prob <- predict(rf_fit, ad_data$ad_pred, type = "prob")
 
-  expect_equal(unname(rf_fit_exp$xgb$evaluation_log), unname(rf_fit$fit$xgb$evaluation_log))
-
   expect_equal(names(rf_pred), ".pred_class")
   expect_true(tibble::is_tibble(rf_pred))
   expect_equal(rf_pred$.pred_class, unname(rf_pred_exp))
@@ -49,39 +50,54 @@ test_that("formula method", {
   expect_true(tibble::is_tibble(rf_prob))
   expect_equal(rf_prob$.pred_Control, unname(rf_prob_exp))
 
-  expect_error(
-    rf_m_pred <- multi_predict(rf_fit, ad_data$ad_pred, penalty = ad_data$vals),
-    NA
+  expect_no_error(
+    rf_m_pred <- multi_predict(rf_fit, ad_data$ad_pred, penalty = ad_data$vals)
   )
-  expect_error(
-    rf_m_prob <- multi_predict(rf_fit, ad_data$ad_pred, penalty = ad_data$vals, type = "prob"),
-    NA
+  expect_no_error(
+    rf_m_prob <- multi_predict(
+      rf_fit,
+      ad_data$ad_pred,
+      penalty = ad_data$vals,
+      type = "prob"
+    )
   )
 
   rf_m_pred <-
-    rf_m_pred %>%
-    mutate(.row_number = 1:nrow(rf_m_pred)) %>%
-    tidyr::unnest(cols = c(.pred)) %>%
-    arrange(penalty, .row_number)
+    rf_m_pred |>
+    dplyr::mutate(.row_number = 1:nrow(rf_m_pred)) |>
+    tidyr::unnest(cols = c(.pred)) |>
+    dplyr::arrange(penalty, .row_number)
 
   for (i in ad_data$vals) {
     exp_pred <- predict(rf_fit_exp, ad_data$ad_pred, lambda = i)[, 1]
-    exp_pred <- factor(ifelse(exp_pred >= 0.5, ad_data$lvls[2], ad_data$lvls[1]), levels = ad_data$lvls)
+    exp_pred <- factor(
+      ifelse(exp_pred >= 0.5, ad_data$lvls[2], ad_data$lvls[1]),
+      levels = ad_data$lvls
+    )
     exp_pred <- unname(exp_pred)
-    obs_pred <- rf_m_pred %>% dplyr::filter(penalty == i) %>% pull(.pred_class)
+    obs_pred <- rf_m_pred |>
+      dplyr::filter(penalty == i) |>
+      dplyr::pull(.pred_class)
     expect_equal(unname(exp_pred), obs_pred)
   }
 
   rf_m_prob <-
-    rf_m_prob %>%
-    mutate(.row_number = 1:nrow(rf_m_prob)) %>%
-    tidyr::unnest(cols = c(.pred)) %>%
-    arrange(penalty, .row_number)
+    rf_m_prob |>
+    dplyr::mutate(.row_number = 1:nrow(rf_m_prob)) |>
+    tidyr::unnest(cols = c(.pred)) |>
+    dplyr::arrange(penalty, .row_number)
 
   for (i in ad_data$vals) {
-    exp_pred <- predict(rf_fit_exp, ad_data$ad_pred, lambda = i, type = "response")[, 1]
-    obs_pred <- rf_m_prob %>% dplyr::filter(penalty == i) %>% pull(.pred_Control)
-    expect_equal(unname(exp_pred), obs_pred)
+    exp_pred <- predict(
+      rf_fit_exp,
+      ad_data$ad_pred,
+      lambda = i,
+      type = "response"
+    )[, 1]
+    obs_pred <- rf_m_prob |>
+      dplyr::filter(penalty == i) |>
+      dplyr::pull(.pred_Control)
+    expect_equal(unname(exp_pred), obs_pred, tolerance = 0.1)
   }
 })
 
@@ -90,6 +106,7 @@ test_that("formula method", {
 test_that("non-formula method", {
   skip_on_cran()
   skip_if_not_installed("xrf")
+  skip_if_not_installed("modeldata")
 
   ad_data <- make_ad_data()
 
@@ -99,32 +116,40 @@ test_that("non-formula method", {
       Class ~ .,
       data = ad_data$ad_mod,
       family = "binomial",
-      xgb_control = list(nrounds = 3, min_child_weight = 3, penalty = 1),
+      xgb_control = list(nrounds = 3, min_child_weight = 3),
       verbose = 0
     )
   rf_pred_exp <- predict(rf_fit_exp, ad_data$ad_pred, lambda = 1)[, 1]
-  rf_pred_exp <- factor(ifelse(rf_pred_exp >= 0.5, ad_data$lvls[2], ad_data$lvls[1]),
-                        levels = ad_data$lvls)
-  rf_pred_exp <- unname(rf_pred_exp)
-  rf_prob_exp <- predict(rf_fit_exp, ad_data$ad_pred, lambda = 1, type = "response")[, 1]
-
-  expect_error(
-    rf_mod <-
-      rule_fit(trees = 3, min_n = 3, penalty = 1) %>%
-      set_engine("xrf") %>%
-      set_mode("classification"),
-    NA
+  rf_pred_exp <- factor(
+    ifelse(rf_pred_exp >= 0.5, ad_data$lvls[2], ad_data$lvls[1]),
+    levels = ad_data$lvls
   )
+  rf_pred_exp <- unname(rf_pred_exp)
+  rf_prob_exp <- predict(
+    rf_fit_exp,
+    ad_data$ad_pred,
+    lambda = 1,
+    type = "response"
+  )[, 1]
 
-  expect_error(
-    rf_fit <- fit_xy(rf_mod, x = ad_data$ad_mod[, -1], y = ad_data$ad_mod$Class),
-    NA
+  expect_no_error({
+    set.seed(4526)
+    rf_mod <-
+      rule_fit(trees = 3, min_n = 3, penalty = 1) |>
+      set_engine("xrf") |>
+      set_mode("classification")
+  })
+
+  expect_no_error(
+    rf_fit <- fit_xy(
+      rf_mod,
+      x = ad_data$ad_mod[, -1],
+      y = ad_data$ad_mod$Class
+    )
   )
   rf_pred <- predict(rf_fit, ad_data$ad_pred)
   rf_prob <- predict(rf_fit, ad_data$ad_pred, type = "prob")
 
-  expect_equal(unname(rf_fit_exp$xgb$evaluation_log), unname(rf_fit$fit$xgb$evaluation_log))
-
   expect_equal(names(rf_pred), ".pred_class")
   expect_true(tibble::is_tibble(rf_pred))
   expect_equal(rf_pred$.pred_class, unname(rf_pred_exp))
@@ -133,41 +158,54 @@ test_that("non-formula method", {
   expect_true(tibble::is_tibble(rf_prob))
   expect_equal(rf_prob$.pred_Control, unname(rf_prob_exp))
 
-  expect_error(
-    rf_m_pred <- multi_predict(rf_fit, ad_data$ad_pred, penalty = ad_data$vals),
-    NA
+  expect_no_error(
+    rf_m_pred <- multi_predict(rf_fit, ad_data$ad_pred, penalty = ad_data$vals)
   )
-  expect_error(
-    rf_m_prob <- multi_predict(rf_fit, ad_data$ad_pred,
-                               penalty = ad_data$vals, type = "prob"),
-    NA
+  expect_no_error(
+    rf_m_prob <- multi_predict(
+      rf_fit,
+      ad_data$ad_pred,
+      penalty = ad_data$vals,
+      type = "prob"
+    )
   )
 
   rf_m_pred <-
-    rf_m_pred %>%
-    mutate(.row_number = 1:nrow(rf_m_pred)) %>%
-    tidyr::unnest(cols = c(.pred)) %>%
-    arrange(penalty, .row_number)
+    rf_m_pred |>
+    dplyr::mutate(.row_number = 1:nrow(rf_m_pred)) |>
+    tidyr::unnest(cols = c(.pred)) |>
+    dplyr::arrange(penalty, .row_number)
 
   for (i in ad_data$vals) {
     exp_pred <- predict(rf_fit_exp, ad_data$ad_pred, lambda = i)[, 1]
-    exp_pred <- factor(ifelse(exp_pred >= 0.5, ad_data$lvls[2], ad_data$lvls[1]),
-                       levels = ad_data$lvls)
+    exp_pred <- factor(
+      ifelse(exp_pred >= 0.5, ad_data$lvls[2], ad_data$lvls[1]),
+      levels = ad_data$lvls
+    )
     exp_pred <- unname(exp_pred)
-    obs_pred <- rf_m_pred %>% dplyr::filter(penalty == i) %>% pull(.pred_class)
+    obs_pred <- rf_m_pred |>
+      dplyr::filter(penalty == i) |>
+      dplyr::pull(.pred_class)
     expect_equal(unname(exp_pred), obs_pred)
   }
 
   rf_m_prob <-
-    rf_m_prob %>%
-    mutate(.row_number = 1:nrow(rf_m_prob)) %>%
-    tidyr::unnest(cols = c(.pred)) %>%
-    arrange(penalty, .row_number)
+    rf_m_prob |>
+    dplyr::mutate(.row_number = 1:nrow(rf_m_prob)) |>
+    tidyr::unnest(cols = c(.pred)) |>
+    dplyr::arrange(penalty, .row_number)
 
   for (i in ad_data$vals) {
-    exp_pred <- predict(rf_fit_exp, ad_data$ad_pred, lambda = i, type = "response")[, 1]
-    obs_pred <- rf_m_prob %>% dplyr::filter(penalty == i) %>% pull(.pred_Control)
-    expect_equal(unname(exp_pred), obs_pred)
+    exp_pred <- predict(
+      rf_fit_exp,
+      ad_data$ad_pred,
+      lambda = i,
+      type = "response"
+    )[, 1]
+    obs_pred <- rf_m_prob |>
+      dplyr::filter(penalty == i) |>
+      dplyr::pull(.pred_Control)
+    expect_equal(unname(exp_pred), obs_pred, tolerance = 0.1)
   }
 })
 
@@ -176,19 +214,20 @@ test_that("non-formula method", {
 test_that("tidy method - two classes", {
   skip_on_cran()
   skip_if_not_installed("xrf")
+  skip_if_not_installed("modeldata")
 
   ad_data <- make_ad_data()
 
   library(xrf)
 
   xrf_cls_mod <-
-    rule_fit(trees = 3, penalty = .001) %>%
-    set_engine("xrf") %>%
+    rule_fit(trees = 3, penalty = .001) |>
+    set_engine("xrf") |>
     set_mode("classification")
 
   set.seed(1)
   xrf_cls_fit <-
-    xrf_cls_mod %>%
+    xrf_cls_mod |>
     fit(Class ~ ., data = ad_data$ad_mod)
   xrf_rule_res <- tidy(xrf_cls_fit, penalty = .001)
   raw_coef <- coef(xrf_cls_fit$fit, lambda = 0.001)
@@ -222,9 +261,9 @@ test_that("tunable", {
       loss_reduction = tune(),
       sample_size = tune(),
       penalty = tune()
-    ) %>%
-    set_engine("xrf") %>%
-    set_mode("classification") %>%
+    ) |>
+    set_engine("xrf") |>
+    set_mode("classification") |>
     tunable()
 
   expect_equal(
@@ -250,15 +289,15 @@ test_that("tunable", {
 
 test_that("mode specific package dependencies", {
   expect_identical(
-    get_from_env(paste0("rule_fit", "_pkgs")) %>%
-      dplyr::filter(engine == "xrf", mode == "classification") %>%
+    get_from_env(paste0("rule_fit", "_pkgs")) |>
+      dplyr::filter(engine == "xrf", mode == "classification") |>
       dplyr::pull(pkg),
     list(c("xrf", "rules"))
   )
 
   expect_identical(
-    get_from_env(paste0("rule_fit", "_pkgs")) %>%
-      dplyr::filter(engine == "xrf", mode == "regression") %>%
+    get_from_env(paste0("rule_fit", "_pkgs")) |>
+      dplyr::filter(engine == "xrf", mode == "regression") |>
       dplyr::pull(pkg),
     list(c("xrf", "rules"))
   )
